==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AssigningRadialStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialStyleEventArgsDescription } from "./AssigningRadialStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningRadialStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningRadialStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningRadialStyleEventArgsDescriptionMetadata.a == null) {
                AssigningRadialStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningRadialStyleEventArgsDescriptionMetadata.c(AssigningRadialStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningRadialStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(AssigningRadialStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningRadialStyleEventArgsDescriptionMetadata.b(a);
            a.ac("AssigningRadialStyleEventArgs", () => new AssigningRadialStyleEventArgsDescription());
            a.ab("AssigningRadialStyleEventArgs", AssigningRadialStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningRadialStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningRadialStyleEventArgsDescriptionMetadata, 'AssigningRadialStyleEventArgsDescriptionMetadata');
    AssigningRadialStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialStyleEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/AssigningRadialStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialStyleEventArgsDescription } from "./AssigningRadialStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningRadialStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningRadialStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningRadialStyleEventArgsDescriptionMetadata.a == null) {
                AssigningRadialStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningRadialStyleEventArgsDescriptionMetadata.c(AssigningRadialStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningRadialStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningRadialStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningRadialStyleEventArgsDescriptionMetadata.b(a);
            a.ae("AssigningRadialStyleEventArgs", () => new AssigningRadialStyleEventArgsDescription());
            a.ad("AssigningRadialStyleEventArgs", AssigningRadialStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningRadialStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningRadialStyleEventArgsDescriptionMetadata, 'AssigningRadialStyleEventArgsDescriptionMetadata');
    AssigningRadialStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialStyleEventArgsDescriptionMetadata;
})();
